@@ -277,7 +277,7 @@ def create_asset(args, os_release, atype, plist, digest, container_fs):
     asset_data['tags'] = asset_tags
 
     if container_fs is not None:
-        host = {'remote' : False}
+        host = {'remote' : False, 'assetid': asset_id}
         plugin_processor.process_plugins(asset_data, host, args, container_fs)
 
     return [ asset_data ]
@@ -301,7 +301,7 @@ def discover_rh_from_container_image(container_fs):
         pkg_resources.get_distribution('rpm')
     except pkg_resources.DistributionNotFound as err:
         logging.warning("%s", err)
-        logging.warning("python-rpm module not found. Please install [python2-rpm] or [python3-rpm] from your distro package manager")
+        logging.warning("python-rpm module not found. Please install [python3-rpm] from your distro package manager")
         return []
     try:
         rpm_module = importlib.import_module('rpm')
@@ -310,7 +310,7 @@ def discover_rh_from_container_image(container_fs):
         return []
 
     if hasattr(rpm_module, 'addMacro') == False:
-            logging.warning('Please install [python2-rpm] or [python3-rpm] from your distro package manager')
+            logging.warning('Please install [python3-rpm] from your distro package manager')
             return []
     plist = []
     rpm_addMacro = getattr(rpm_module, 'addMacro')
@@ -385,7 +385,7 @@ def create_open_source_asset(args, container_fs, digest):
     os_asset_id = get_opensource_asset_id(args)
     # skip unused dependencies filtering for container app assets
     args.include_unused_dependencies = True
-    oa = repo.discover_inventory(args, container_fs)
+    oa = repo.discover_inventory(args, container_fs, container_fs)
     if oa != None and len(oa[0]['products']) != 0:
         if args.assetname is not None:
             oa[0]['name'] = args.assetname+'-container-app'
@@ -423,7 +423,6 @@ def discover_container_from_image(args, digest):
             logging.warning("Unable to analyze container filesystem")
             shutil.rmtree(temp_dir, onerror = on_rm_error)
             return None
-
         fix_symbolic_links(container_fs)
 
         oa = create_open_source_asset(args, container_fs, digest)
@@ -442,7 +441,16 @@ def discover_container_from_image(args, digest):
             return casset 
 
         plist = None
-        if atype == 'CentOS' or atype == 'Red Hat' or atype == 'Amazon Linux' or atype == 'Oracle Linux':
+        if atype == 'CentOS' or atype == 'Red Hat' or atype == 'Amazon Linux' or atype == 'Oracle Linux' or atype == 'Rocky Linux':
+            if atype == 'Rocky Linux':
+                # Presence of rpm db lock files causes an issue on Rocky Linux
+                rpm_folder = container_fs + os.path.sep + os.path.sep.join(["var","lib","rpm"])
+                rpm_folder_files = utils.find_files(rpm_folder, '')
+                rpm_lock_pattern = re.compile(r'\.*__db\.[0-9]+$')
+                for rpm_folder_file in rpm_folder_files:
+                    if rpm_lock_pattern.search(rpm_folder_file):
+                        os.remove(rpm_folder_file)
+                        logging.debug("Deleted rpm db lock file [%s]", rpm_folder_file)
             plist = discover_rh_from_container_image(container_fs)
         elif atype == 'Ubuntu' or atype == 'Debian':
             plist = discover_ubuntu_from_container_image(container_fs)
